Class: Jbr::Mock

Inherits:
Object
  • Object
show all
Defined in:
lib/jbr/mock.rb

Overview

What an app under test wants Jobber to answer.

Defined Under Namespace

Classes: Account, Invoice, Job, OAuth, Quote, Request, URL, Visit

Instance Attribute Summary collapse

Instance Attribute Details

#invoiceObject

The canned answers, each read by the matching Mock resource.



5
6
7
# File 'lib/jbr/mock.rb', line 5

def invoice
  @invoice
end

#jobObject

The canned answers, each read by the matching Mock resource.



5
6
7
# File 'lib/jbr/mock.rb', line 5

def job
  @job
end

#oauth_errorObject

The canned answers, each read by the matching Mock resource.



5
6
7
# File 'lib/jbr/mock.rb', line 5

def oauth_error
  @oauth_error
end

#oauth_urlObject

The canned answers, each read by the matching Mock resource.



5
6
7
# File 'lib/jbr/mock.rb', line 5

def oauth_url
  @oauth_url
end

#quoteObject

The canned answers, each read by the matching Mock resource.



5
6
7
# File 'lib/jbr/mock.rb', line 5

def quote
  @quote
end

#requestObject

The canned answers, each read by the matching Mock resource.



5
6
7
# File 'lib/jbr/mock.rb', line 5

def request
  @request
end

#visitsObject

The canned answers, each read by the matching Mock resource.



5
6
7
# File 'lib/jbr/mock.rb', line 5

def visits
  @visits
end