Class: Jbr::Mock
- Inherits:
-
Object
- Object
- Jbr::Mock
- Defined in:
- lib/jbr/mock.rb
Overview
What an app under test wants Jobber to answer.
Defined Under Namespace
Classes: Account, Invoice, Job, OAuth, Quote, Request, URL, Visit
Instance Attribute Summary collapse
-
#invoice ⇒ Object
The canned answers, each read by the matching Mock resource.
-
#job ⇒ Object
The canned answers, each read by the matching Mock resource.
-
#oauth_error ⇒ Object
The canned answers, each read by the matching Mock resource.
-
#oauth_url ⇒ Object
The canned answers, each read by the matching Mock resource.
-
#quote ⇒ Object
The canned answers, each read by the matching Mock resource.
-
#request ⇒ Object
The canned answers, each read by the matching Mock resource.
-
#visits ⇒ Object
The canned answers, each read by the matching Mock resource.
Instance Attribute Details
#invoice ⇒ Object
The canned answers, each read by the matching Mock resource.
5 6 7 |
# File 'lib/jbr/mock.rb', line 5 def invoice @invoice end |
#job ⇒ Object
The canned answers, each read by the matching Mock resource.
5 6 7 |
# File 'lib/jbr/mock.rb', line 5 def job @job end |
#oauth_error ⇒ Object
The canned answers, each read by the matching Mock resource.
5 6 7 |
# File 'lib/jbr/mock.rb', line 5 def oauth_error @oauth_error end |
#oauth_url ⇒ Object
The canned answers, each read by the matching Mock resource.
5 6 7 |
# File 'lib/jbr/mock.rb', line 5 def oauth_url @oauth_url end |
#quote ⇒ Object
The canned answers, each read by the matching Mock resource.
5 6 7 |
# File 'lib/jbr/mock.rb', line 5 def quote @quote end |
#request ⇒ Object
The canned answers, each read by the matching Mock resource.
5 6 7 |
# File 'lib/jbr/mock.rb', line 5 def request @request end |
#visits ⇒ Object
The canned answers, each read by the matching Mock resource.
5 6 7 |
# File 'lib/jbr/mock.rb', line 5 def visits @visits end |